API-Reference — Collectors v0.2 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Collectors v0.2 documentation »

# API-Reference

API-Reference for Collectors.

- `collectors.core` — Core classes
- `collectors.shortcuts` — Useful shortcut functions
- `collectors.storage` — Advanced storage backends

For your convenience, the following classes and functions are imported in the collectors namespace and thus can easily be imported directly from `collectors`:

- `collectors.core.Collector`
- `collectors.shortcuts.get()`
- `collectors.shortcuts.get_objects()`
- `collectors.shortcuts.manual()`

### Navigation

- index
- modules |
- next |
- previous |
- Collectors v0.2 documentation »